# 自定义侧栏插件

Endstone平台的自定义侧栏插件

## 支持的变量

- [x] `{x}` x坐标
- [x] `{y}` y坐标
- [x] `{z}` z坐标
- [x] `{player_name}` 玩家名称
- [x] `{dimension}` 维度名称
- [x] `{dimension_id}` 维度ID
- [x] `{ping}` 玩家延迟
- [x] `{date}` 日期
- [x] `{time}` 时间
- [x] `{datetime}` 日期和时间
- [x] `{year}` 年份
- [x] `{month}` 月份
- [x] `{day}` 天
- [x] `{hour}` 小时
- [x] `{minute}` 分钟
- [x] `{second}` 秒
- [x] `{mc_version}` minecraft版本
- [x] `{online}` 在线玩家数
- [x] `{max_online}` 最大在线玩家数
- [x] `{address}` 玩家IP地址
- [x] `{runtime_id}` 玩家运行时id
- [x] `{exp_level}` 玩家经验等级
- [x] `{total_exp}` 玩家总经验
- [x] `{exp_progress}` 玩家经验进度
- [x] `{game_mode}` 玩家游戏模式
- [x] `{xuid}` 玩家xuid
- [x] `{uuid}` 玩家uuid
- [x] `{device_os}` 玩家当前设备操作系统名称
- [x] `{locale}` 玩家语言

## 安装

- 从[release](https://github.com/endstone-essentials/sidebar/releases)或者[action](https://github.com/endstone-essentials/sidebar/actions/workflows/build.yml)下载whl文件
- 将其放到`plugins`文件夹
- 重启服务器

## 要求

Python: 3.10+

Endstone: 0.5.1.dev28+